Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon GroundTruth Labeling.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for Amazon GroundTruth Labeling - AWS Identity and Access Management

# Actions, resources, and condition keys for Amazon GroundTruth Labeling

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongroundtruthlabeling.html .

Amazon GroundTruth Labeling (service prefix: `groundtruthlabeling` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon GroundTruth Labeling
- Resource types defined by Amazon GroundTruth Labeling
- Condition keys for Amazon GroundTruth Labeling

## Actions defined by Amazon GroundTruth Labeling

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
DescribeConsoleJob [permission only] | Get status of GroundTruthLabeling Jobs. | Read |  |  |
ListDatasetObjects [permission only] | Paginated list API to list dataset objects in a manifest file. | Read |  |  |
RunFilterOrSampleDatasetJob [permission only] | Filter records from a manifest file using S3 select. Get sample entries based on random sampling. | Write |  |  |
RunGenerateManifestByCrawlingJob [permission only] | List a S3 prefix and create manifest files from objects in that location. | Write |  |  |

## Resource types defined by Amazon GroundTruth Labeling

Amazon GroundTruth Labeling does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon GroundTruth Labeling, specify `“Resource”: “*”` in your policy.

## Condition keys for Amazon GroundTruth Labeling

GroundTruth Labeling has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.